==> icingaweb2-module-businessprocess_2.3.0.orig.tar.xz: icingaweb2-module-businessprocess-2.3.0/doc/05-Importing-Processes.md <==
<a id="Importing-Processes"></a>Importing Processes
===================================================

To avoid redundancy and make complex *Business Process Configurations* easier
to maintain it is possible to import processes from other configurations.

In order to be able to import a process create a root node first. You cannot
import processes into the root level.

![Subprocesses Only](screenshot/05_importing_nodes/0401_subprocesses_only.png)

Importing a Process
-------------------

Once the related configuration form is open, choose `Existing Process` and wait
for the form to refresh.

![Existing Process](screenshot/05_importing_nodes/0402_choose_existing_process.png)

### Choose Configuration

You can now choose the configuration to import processes from. Or simply hit
`Next` to just utilize a process from the current configuration.

![Choose Configuration](screenshot/05_importing_nodes/0403_choose_configuration.png)

### Select Processes

Now select the processes you want to import and submit the form.

![Select Processes](screenshot/05_importing_nodes/0404_choose_process.png)

### Import Successful

You are now looking at the result. The process has been imported. Do not forget
to save your changes!

![Import Successful](screenshot/05_importing_nodes/0405_import_successful.png)

Navigation with Imported Processes
----------------------------------

### Seamless Breadcrumbs

You may have already noticed that the breadcrumbs integrate the hierarchy
of the imported process. Once you navigate further the actions below the
breadcrumbs change and don't permit to unlock editing.

![Seamless Breadcrumbs](screenshot/05_importing_nodes/0406_breadcrumb_integration.png)

To change imported processes you need to open them in their original
configuration first. To do so click on the arrow to the right which is
displayed in a tile's action urls in the upper left. While in tree view
these can be found at the very right of an process' row.

![Jump To Original](screenshot/05_importing_nodes/0407_jump_to_original.png)

==> icingaweb2-module-businessprocess_2.5.1.orig.tar.xz: icingaweb2-module-businessprocess-2.5.1/doc/05-Importing-Processes.md <==
# Importing Processes

To avoid redundancy and make complex *Business Process Configurations* easier
to maintain it is possible to import processes from other configurations.

In order to be able to import a process create a root node first. You cannot
import processes into the root level.

![Subprocesses Only](screenshot/05_importing_nodes/0401_subprocesses_only.png)

## Importing a Process

Once the related configuration form is open, choose `Existing Process` and wait
for the form to refresh.

![Existing Process](screenshot/05_importing_nodes/0402_choose_existing_process.png)

### Choose Configuration

You can now choose the configuration to import processes from. Or simply hit
`Next` to just utilize a process from the current configuration.

![Choose Configuration](screenshot/05_importing_nodes/0403_choose_configuration.png)

### Select Processes

Now select the processes you want to import and submit the form.

![Select Processes](screenshot/05_importing_nodes/0404_choose_process.png)

### Import Successful

You are now looking at the result. The process has been imported. Do not forget
to save your changes!

![Import Successful](screenshot/05_importing_nodes/0405_import_successful.png)

## Navigation with Imported Processes

### Seamless Breadcrumbs

You may have already noticed that the breadcrumbs integrate the hierarchy
of the imported process. Once you navigate further the actions below the
breadcrumbs change and don't permit to unlock editing.

![Seamless Breadcrumbs](screenshot/05_importing_nodes/0406_breadcrumb_integration.png)

To change imported processes you need to open them in their original
configuration first. To do so click on the arrow to the right which is
displayed in a tile's action urls in the upper left. While in tree view
these can be found at the very right of an process' row.

![Jump To Original](screenshot/05_importing_nodes/0407_jump_to_original.png)
